"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
var core_1 = require('@angular/core');
var notification_service_1 = require('./notification-service');
var app_config_1 = require('../../services/context/app-config');
var gtm_1 = require('../../services/context/gtm');
var styles = require('!!css-loader!less-loader!./notification.less');
var Notification = (function () {
    function Notification(notificationService, gtmService, appConfig) {
        this.notificationService = notificationService;
        this.gtmService = gtmService;
        this.appConfig = appConfig;
        this.iconCssPrefix = 'glyphicon';
        this.baseColor = 'empty';
        this.hide = false;
        this.icon = this.iconCssPrefix + " " + this.iconCssPrefix + "-alert";
        this.hideTime = 1000;
        this.fadeTime = 4000;
        var app = this.appConfig.gtmAppName || this.appConfig.appBasePath;
        this.defaultErrorAction = app ? 'Action not provided from app ' + app : 'Error from NG2UEUtils Notification component';
    }
    Notification.prototype.show = function (message, type, gtmAction) {
        var _this = this;
        this.notification = message;
        switch (type) {
            case 'success':
                this.fadeTimerHandle = setTimeout(function () { return _this.close(); }, this.fadeTime);
                this.setIconClass('ok');
                this.baseColor = 'success';
                break;
            case 'warning':
                this.setIconClass('alert');
                this.baseColor = 'warning';
                break;
            default:
                this.logUserVisibleError(message, gtmAction);
                this.setIconClass('alert');
                this.baseColor = 'error';
                break;
        }
    };
    Notification.prototype.setIconClass = function (type) {
        this.icon = this.iconCssPrefix + " " + this.iconCssPrefix + "-" + type;
    };
    Notification.prototype.close = function () {
        var _this = this;
        this.hide = true;
        setTimeout(function () {
            _this.fadeTimerHandle = undefined;
            _this.notification = undefined;
            _this.baseColor = 'empty';
            _this.hide = false;
        }, this.hideTime);
    };
    Notification.prototype.resetTimer = function () {
        if (this.fadeTimerHandle) {
            clearTimeout(this.fadeTimerHandle);
        }
    };
    Notification.prototype.restartTimer = function () {
        var _this = this;
        if (this.fadeTimerHandle) {
            this.fadeTimerHandle = setTimeout(function () { return _this.close(); }, this.fadeTime);
        }
    };
    Notification.prototype.ngOnInit = function () {
        var _this = this;
        this.serviceSubscription = this.notificationService.observe$.subscribe(function (notification) {
            _this.show(notification.message, notification.type, notification.gtmAction);
        });
    };
    Notification.prototype.ngOnDestroy = function () {
        this.serviceSubscription.unsubscribe();
        this.serviceSubscription = undefined;
    };
    Notification.prototype.logUserVisibleError = function (message, gtmAction) {
        this.gtmService.registerUserVisibleError(message, gtmAction);
    };
    __decorate([
        core_1.Input(), 
        __metadata('design:type', String)
    ], Notification.prototype, "iconCssPrefix", void 0);
    Notification = __decorate([
        core_1.Component({
            selector: 'notification',
            styles: [styles.toString()],
            template: "\n    <div class=\"notification-container ut-root-element\" [ngClass]=\"baseColor\" [class.show]=\"notification\" [class.hide]=\"hide\">\n        <div class=\"notification-content\" (mouseover)=\"resetTimer()\" (mouseout)=\"restartTimer()\">\n            <div aria-hidden=\"true\" class=\"close\" (click)=\"close()\">x</div>\n            <div><span class=\"ut-icon\" [ngClass]=\"icon\"></span><span class=\"main-text ut-main-text\">{{ notification }}</span></div>\n        </div>\n    </div>\n    "
        }),
        __param(2, core_1.Inject(app_config_1.APP_CONFIG)), 
        __metadata('design:paramtypes', [notification_service_1.NotificationService, gtm_1.GTMService, Object])
    ], Notification);
    return Notification;
}());
exports.Notification = Notification;
//# sourceMappingURL=notification.js.map