"use strict";
var jwt_1 = require('./jwt');
var Cookie = (function () {
    function Cookie(key, value) {
        this.key = key;
        this.value = value;
    }
    return Cookie;
}());
exports.Cookie = Cookie;
var ContextHelper = (function () {
    function ContextHelper(window) {
        var _this = this;
        this.window = window;
        this.getUser = function () {
            return _this.getSessionContext().email;
        };
        this.getUuid = function () {
            return _this.getSessionContext().uuid;
        };
        this.getSessionContext = function () {
            var cookieContext = _this.sessionContext();
            if (cookieContext) {
                return JSON.parse(atob(cookieContext));
            }
            else if (_this.accessToken()) {
                return {
                    email: _this.jwt().user,
                    uuid: _this.jwt().uuid
                };
            }
            else {
                return {
                    email: '',
                    uuid: ''
                };
            }
        };
        this.sessionContext = function () { return _this.cookie('session_context'); };
        this.accessToken = function () { return _this.cookie('access_token'); };
        this.jwt = function () { return new jwt_1.Jwt(_this.accessToken()); };
    }
    ContextHelper.prototype.orgNameFromPath = function (path) {
        var parts = /^\/(?:o|organizations)\/([^\/]+)\//.exec(path);
        if (parts && parts.length > 1) {
            return parts[1];
        }
    };
    ContextHelper.prototype.orgNameFromLocal = function () {
        var name = this.window.getLocal('organization');
        if (!name && name !== undefined) {
            name = undefined;
        }
        return name;
    };
    ContextHelper.prototype.orgNameToLocal = function (name) {
        this.window.setLocal('organization', name);
    };
    ContextHelper.prototype.cookies = function () {
        var docCookie = this.window.cookies();
        if (docCookie) {
            return docCookie.split(';').map(function (c) {
                var pair = c.split('=');
                if (pair.length >= 2) {
                    return { key: pair[0].trim(), value: pair[1].trim() };
                }
                return { key: c, value: c };
            });
        }
        return [];
    };
    ContextHelper.prototype.cookie = function (key) {
        var c = this.cookies().find(function (cc) { return cc.key === key; });
        if (c) {
            return c.value;
        }
    };
    return ContextHelper;
}());
exports.ContextHelper = ContextHelper;
var ContextHelper;
(function (ContextHelper) {
    'use strict';
})(ContextHelper = exports.ContextHelper || (exports.ContextHelper = {}));
//# sourceMappingURL=context-helper.js.map